@@ -70,34 +70,38 @@ class DatabaseWrapper(BaseDatabaseWrapper):
 
     data_types = {
         'AutoField': 'serial',
-        'BigAutoField': 'bigserial',
+        'BigAutoField': 'serial8',
         'BinaryField': 'blob',
         'BooleanField': 'boolean',
-        'CharField': 'lvarchar(%(max_length)s)',
-        'CommaSeparatedIntegerField': 'lvarchar(%(max_length)s)',
+        'CharField': 'varchar(%(max_length)s)',
+        'CommaSeparatedIntegerField': 'varchar(%(max_length)s)',
         'DateField': 'date',
         'DateTimeField': 'datetime year to fraction(5)',
-        'DecimalField': 'decimal',
+        'DecimalField': 'decimal(%(max_digits)s, %(decimal_places)s)',
         'DurationField': 'interval',
-        'FileField': 'lvarchar(%(max_length)s)',
-        'FilePathField': 'lvarchar(%(max_length)s)',
+        'FileField': 'varchar(%(max_length)s)',
+        'FilePathField': 'varchar(%(max_length)s)',
         'FloatField': 'smallfloat',
         'IntegerField': 'integer',
-        'BigIntegerField': 'bigint',
-        'IPAddressField': 'char(15)',
-        'GenericIPAddressField': 'char(39)',
+        'BigIntegerField': 'int8',
+        'IPAddressField': 'varchar(15)',
+        'GenericIPAddressField': 'varchar(39)',
         'NullBooleanField': 'boolean',
         'OneToOneField': 'integer',
+        'PositiveBigIntegerField': 'int8',
         'PositiveIntegerField': 'integer',
         'PositiveSmallIntegerField': 'smallint',
-        'SlugField': 'lvarchar(%(max_length)s)',
+        'SlugField': 'varchar(%(max_length)s)',
         'SmallIntegerField': 'smallint',
-        'TextField': 'lvarchar(%(max_length)s)',
+        'TextField': 'varchar(%(max_length)s)',
         'TimeField': 'datetime hour to second',
-        'UUIDField': 'char(32)',
+        'UUIDField': 'varchar(36)',
+        'JSONField': 'varchar(4096)',
+        'URLField': 'varchar(1024)',
     }
 
     data_type_check_constraints = {
+        'PositiveBigIntegerField': '%(column)s >= 0',
         'PositiveIntegerField': '%(column)s >= 0',
         'PositiveSmallIntegerField': '%(column)s >= 0',
     }
