@@ -14,13 +14,16 @@ class DatabaseOperations(BaseDatabaseOperations):
     def quote_name(self, name):
         return name
 
+    def max_in_list_size(self):
+        return 1000
+
     def last_insert_id(self, cursor, table_name, pk_name):
-        operation = "SELECT DBINFO('sqlca.sqlerrd1') FROM SYSTABLES WHERE TABID=1"
+        operation = "SELECT DBINFO('sqlca.sqlerrd1'),DBINFO('serial8') FROM DUAL"
         cursor.execute(operation)
         row = cursor.fetchone()
         last_identity_val = None
         if row is not None:
-            last_identity_val = int(row[0])
+            last_identity_val = int(row[0]) + int(row[1])
         return last_identity_val
 
     def fulltext_search_sql(self, field_name):
