@@ -24,6 +24,8 @@ class DatabaseSchemaEditor(BaseDatabaseSchemaEditor):
         This silences the error when Django tries to do the same thing independently
         """
         try:
+            if "CREATE TABLE" in str(sql) or "ALTER TABLE" in str(sql) :
+                sql = str(sql).replace('varchar(None)','varchar(255)')
             super(DatabaseSchemaEditor, self).execute(sql, params)
         except (ProgrammingError, DatabaseError) as e:
             if "CREATE INDEX" not in str(sql) and 'Index already exists' not in str(e):
